# Changelog

See the [GitHub Releases](https://github.com/montanarograziano/spark_plan_viz/releases) page for the full changelog, which is auto-generated from conventional commits using [git-cliff](https://git-cliff.org/).
